@@ -6,10 +6,10 @@ Tag-expressions are used in cucumber, behave and other BDD frameworks
 to select features, scenarios, etc. in `Gherkin`_ files.
 Theses selected items are normally included in a test run.
 
-.. see also:: https://docs.cucumber.io/cucumber/api/#tag-expressions
+.. see also:: https://cucumber.io/docs/cucumber/api/#tag-expressions
 
-.. _`cucumber tag-expressions`: https://docs.cucumber.io/cucumber/api/#tag-expressions
-.. _`Gherkin`: https://docs.cucumber.io/gherkin/reference/
+.. _`cucumber tag-expressions`: https://cucumber.io/docs/cucumber/api/#tag-expressions
+.. _`Gherkin`: https://cucumber.io/docs/gherkin/reference/
 .. _`behave: Gherkin`: https://behave.readthedocs.io/en/latest/philosophy.html#the-gherkin-language
 """
 
